import hal
import glib
import hal_glib
import time
import gtk # for image references
from inspect import stack

#---create a variable with filenames that can be loaded index---
vfd_img_files  = ( "./images/0-fault-lockout.gif", 
                 "./images/1-fault.gif",
                 "./images/2-start-pending.gif",
                 "./images/3-stop.gif",
                 "./images/4-dc-brake.gif",
                 "./images/5-run-at-0hz.gif",
                 "./images/6-run.gif",
                 "./images/7-accel.gif",
                 "./images/8-decel.gif",
                 "./images/9-current-limit.gif",
                 "./images/10-decel-override.gif",
                 "./images/11-lower-transistors-switchin-on.gif")
                 
# boiler code to register our handler
def get_handlers(halcomp,builder,useropts):
    return [HandlerClass(halcomp,builder,useropts)]

class HandlerClass:
    def __init__(self, halcomp,builder,useropts):
        self.builder = builder
        self.halcomp = halcomp
        self.jog_increment = self.builder.get_object('jog_increment')
        self.g54inch = self.builder.get_object('g54inch_jog')
        self.g54tenths = self.builder.get_object('g54tenth_jog')
        self.g54hundredths = self.builder.get_object('g54hundedth_jog')
        self.g54thousandths = self.builder.get_object('g54thousandth_jog')
        self.vac_on = self.builder.get_object('vac_on')
        self.vac_off = self.builder.get_object('vac_off')
        self.on_vacuum_state = hal_glib.GPin(halcomp.newpin('on-vacuum-state', hal.HAL_BIT, hal.HAL_IN))
        self.off_vacuum_state = hal_glib.GPin(halcomp.newpin('off-vacuum-state', hal.HAL_BIT, hal.HAL_IN))
        self.on_vacuum_state.connect('value-changed', self.on_vacuum_state_value_changed)
        self.off_vacuum_state.connect('value-changed', self.off_vacuum_state_value_changed)
#get spindle button statuses 
        self.en_spindle_Z1 = self.builder.get_object('en-spin-z1')
        self.en_spindle_Z2 = self.builder.get_object('en-spin-z2')
        self.en_spindle_Z3 = self.builder.get_object('en-spin-z3')
        self.en_spindle_Z4 = self.builder.get_object('en-spin-z4')
        self.en_spindle_Z5 = self.builder.get_object('en-spin-z5')
        self.en_spindle_Z6 = self.builder.get_object('en-spin-z6')
        self.en_spindle_Z7 = self.builder.get_object('en-spin-z7')
        self.en_spindle_Z8 = self.builder.get_object('en-spin-z8')
#Create Hal Pins for Spindle Enable and Disable
        self.enable_spindle_Z1 = hal_glib.GPin(halcomp.newpin('enable-Z1', hal.HAL_BIT, hal.HAL_IN))
        self.enable_spindle_Z1.connect('value-changed', self.enable_spindle_Z1_value_changed)
        self.disable_spindle_Z1 = hal_glib.GPin(halcomp.newpin('disable-Z1', hal.HAL_BIT, hal.HAL_IN))
        self.disable_spindle_Z1.connect('value-changed', self.disable_spindle_Z1_value_changed)
        
        self.enable_spindle_Z2 = hal_glib.GPin(halcomp.newpin('enable-Z2', hal.HAL_BIT, hal.HAL_IN))
        self.enable_spindle_Z2.connect('value-changed', self.enable_spindle_Z2_value_changed)
        self.disable_spindle_Z2 = hal_glib.GPin(halcomp.newpin('disable-Z2', hal.HAL_BIT, hal.HAL_IN))
        self.disable_spindle_Z2.connect('value-changed', self.disable_spindle_Z2_value_changed)
        
        self.enable_spindle_Z3 = hal_glib.GPin(halcomp.newpin('enable-Z3', hal.HAL_BIT, hal.HAL_IN))
        self.enable_spindle_Z3.connect('value-changed', self.enable_spindle_Z3_value_changed)
        self.disable_spindle_Z3 = hal_glib.GPin(halcomp.newpin('disable-Z3', hal.HAL_BIT, hal.HAL_IN))
        self.disable_spindle_Z3.connect('value-changed', self.disable_spindle_Z3_value_changed)
        
        self.enable_spindle_Z4 = hal_glib.GPin(halcomp.newpin('enable-Z4', hal.HAL_BIT, hal.HAL_IN))
        self.enable_spindle_Z4.connect('value-changed', self.enable_spindle_Z4_value_changed)
        self.disable_spindle_Z4 = hal_glib.GPin(halcomp.newpin('disable-Z4', hal.HAL_BIT, hal.HAL_IN))
        self.disable_spindle_Z4.connect('value-changed', self.disable_spindle_Z4_value_changed)  
        
        self.enable_spindle_Z5 = hal_glib.GPin(halcomp.newpin('enable-Z5', hal.HAL_BIT, hal.HAL_IN))
        self.enable_spindle_Z5.connect('value-changed', self.enable_spindle_Z5_value_changed)
        self.disable_spindle_Z5 = hal_glib.GPin(halcomp.newpin('disable-Z5', hal.HAL_BIT, hal.HAL_IN))
        self.disable_spindle_Z5.connect('value-changed', self.disable_spindle_Z5_value_changed)
        
        self.enable_spindle_Z6 = hal_glib.GPin(halcomp.newpin('enable-Z6', hal.HAL_BIT, hal.HAL_IN))
        self.enable_spindle_Z6.connect('value-changed', self.enable_spindle_Z6_value_changed)
        self.disable_spindle_Z6 = hal_glib.GPin(halcomp.newpin('disable-Z6', hal.HAL_BIT, hal.HAL_IN))
        self.disable_spindle_Z6.connect('value-changed', self.disable_spindle_Z6_value_changed)

        self.enable_spindle_Z7 = hal_glib.GPin(halcomp.newpin('enable-Z7', hal.HAL_BIT, hal.HAL_IN))
        self.enable_spindle_Z7.connect('value-changed', self.enable_spindle_Z7_value_changed)
        self.disable_spindle_Z7 = hal_glib.GPin(halcomp.newpin('disable-Z7', hal.HAL_BIT, hal.HAL_IN))
        self.disable_spindle_Z7.connect('value-changed', self.disable_spindle_Z7_value_changed)

        self.enable_spindle_Z8 = hal_glib.GPin(halcomp.newpin('enable-Z8', hal.HAL_BIT, hal.HAL_IN))
        self.enable_spindle_Z8.connect('value-changed', self.enable_spindle_Z8_value_changed)
        self.disable_spindle_Z8 = hal_glib.GPin(halcomp.newpin('disable-Z8', hal.HAL_BIT, hal.HAL_IN))
        self.disable_spindle_Z8.connect('value-changed', self.disable_spindle_Z8_value_changed)                
                
#Create hal pins for VFD status images
        vfd_msg1 = hal_glib.GPin(halcomp.newpin('msg-vfd1', hal.HAL_U32, hal.HAL_IN))
        vfd_msg1.connect('value-changed', self._on_vfd_msg1_change)
        vfd_msg2 = hal_glib.GPin(halcomp.newpin('msg-vfd2', hal.HAL_U32, hal.HAL_IN))
        vfd_msg2.connect('value-changed', self._on_vfd_msg2_change)
        vfd_msg3 = hal_glib.GPin(halcomp.newpin('msg-vfd3', hal.HAL_U32, hal.HAL_IN))
        vfd_msg3.connect('value-changed', self._on_vfd_msg3_change)
        vfd_msg4 = hal_glib.GPin(halcomp.newpin('msg-vfd4', hal.HAL_U32, hal.HAL_IN))
        vfd_msg4.connect('value-changed', self._on_vfd_msg4_change)
        vfd_msg5 = hal_glib.GPin(halcomp.newpin('msg-vfd5', hal.HAL_U32, hal.HAL_IN))
        vfd_msg5.connect('value-changed', self._on_vfd_msg5_change)
        vfd_msg6 = hal_glib.GPin(halcomp.newpin('msg-vfd6', hal.HAL_U32, hal.HAL_IN))
        vfd_msg6.connect('value-changed', self._on_vfd_msg6_change)
        vfd_msg7 = hal_glib.GPin(halcomp.newpin('msg-vfd7', hal.HAL_U32, hal.HAL_IN))
        vfd_msg7.connect('value-changed', self._on_vfd_msg7_change)
        vfd_msg8 = hal_glib.GPin(halcomp.newpin('msg-vfd8', hal.HAL_U32, hal.HAL_IN))
        vfd_msg8.connect('value-changed', self._on_vfd_msg8_change)

#Use the hal pin value to choose the image displayed
    def _on_vfd_msg1_change(self,hal_pin,data=None):
        self.builder.get_object('img-vfd1').set_from_file( vfd_img_files[ self.halcomp['msg-vfd1'] ] )

    def _on_vfd_msg2_change(self,hal_pin,data=None):
        self.builder.get_object('img-vfd2').set_from_file( vfd_img_files[ self.halcomp['msg-vfd2'] ] )

    def _on_vfd_msg3_change(self,hal_pin,data=None):
        self.builder.get_object('img-vfd3').set_from_file( vfd_img_files[ self.halcomp['msg-vfd3'] ] )

    def _on_vfd_msg4_change(self,hal_pin,data=None):
        self.builder.get_object('img-vfd4').set_from_file( vfd_img_files[ self.halcomp['msg-vfd4'] ] )

    def _on_vfd_msg5_change(self,hal_pin,data=None):
        self.builder.get_object('img-vfd5').set_from_file( vfd_img_files[ self.halcomp['msg-vfd5'] ] )

    def _on_vfd_msg6_change(self,hal_pin,data=None):
        self.builder.get_object('img-vfd6').set_from_file( vfd_img_files[ self.halcomp['msg-vfd6'] ] )

    def _on_vfd_msg7_change(self,hal_pin,data=None):
        self.builder.get_object('img-vfd7').set_from_file( vfd_img_files[ self.halcomp['msg-vfd7'] ] )

    def _on_vfd_msg8_change(self,hal_pin,data=None):
        self.builder.get_object('img-vfd8').set_from_file( vfd_img_files[ self.halcomp['msg-vfd8'] ] )
        
    def activ_inc(self, widget):
        if widget.get_active():
            if widget == self.g54inch: self.jog_increment.set_text('1.000')
            elif widget == self.g54tenths: self.jog_increment.set_text('0.100')
            elif widget == self.g54hundredths:  self.jog_increment.set_text('0.010')
            elif widget == self.g54thousandths: self.jog_increment.set_text('0.001')

#Change state of VCP button by hal pin
    def on_vacuum_state_value_changed(self, pin):
        state = pin.get()
        if state:
            self.vac_on.set_active(True)
    def off_vacuum_state_value_changed(self, pin):
        state = pin.get()
        if state:
            self.vac_off.set_active(True)

    def enable_spindle_Z1_value_changed(self, pin):
        state = pin.get()
        if state:
            self.en_spindle_Z1.set_active(True)
    def disable_spindle_Z1_value_changed(self, pin):
        state = pin.get()
        if state:
            self.en_spindle_Z1.set_active(False)

    def enable_spindle_Z2_value_changed(self, pin):
        state = pin.get()
        if state:
            self.en_spindle_Z2.set_active(True)
    def disable_spindle_Z2_value_changed(self, pin):
        state = pin.get()
        if state:
            self.en_spindle_Z2.set_active(False)

    def enable_spindle_Z3_value_changed(self, pin):
        state = pin.get()
        if state:
            self.en_spindle_Z3.set_active(True)
    def disable_spindle_Z3_value_changed(self, pin):
        state = pin.get()
        if state:
            self.en_spindle_Z3.set_active(False)
    
    def enable_spindle_Z4_value_changed(self, pin):
        state = pin.get()
        if state:
            self.en_spindle_Z4.set_active(True)
    def disable_spindle_Z4_value_changed(self, pin):
        state = pin.get()
        if state:
            self.en_spindle_Z4.set_active(False)
    
    def enable_spindle_Z5_value_changed(self, pin):
        state = pin.get()
        if state:
            self.en_spindle_Z5.set_active(True)
    def disable_spindle_Z5_value_changed(self, pin):
        state = pin.get()
        if state:
            self.en_spindle_Z5.set_active(False)
    
    def enable_spindle_Z6_value_changed(self, pin):
        state = pin.get()
        if state:
            self.en_spindle_Z6.set_active(True)
    def disable_spindle_Z6_value_changed(self, pin):
        state = pin.get()
        if state:
            self.en_spindle_Z6.set_active(False)
    
    def enable_spindle_Z7_value_changed(self, pin):
        state = pin.get()
        if state:
            self.en_spindle_Z7.set_active(True)
    def disable_spindle_Z7_value_changed(self, pin):
        state = pin.get()
        if state:
            self.en_spindle_Z7.set_active(False)
    
    def enable_spindle_Z8_value_changed(self, pin):
        state = pin.get()
        if state:
            self.en_spindle_Z8.set_active(True)
    def disable_spindle_Z8_value_changed(self, pin):
        state = pin.get()
        if state:
            self.en_spindle_Z8.set_active(False)
        
# This is boiler code, required for gladevcp
def get_handlers(halcomp,builder,useropts):
    return [HandlerClass(halcomp,builder,useropts)]
